===================
``spelling`` module
===================

See :doc:`correcting errors in user queries <../spelling>`.

.. automodule:: whoosh.spelling


Corrector objects
=================

.. autoclass:: Corrector
    :members:

.. autoclass:: ReaderCorrector

.. autoclass:: GraphCorrector
    :members:

.. autoclass:: MultiCorrector


QueryCorrector objects
======================

.. autoclass:: QueryCorrector
    :members:

.. autoclass:: SimpleQueryCorrector

.. autoclass:: Correction


